"use client";

import { useInView } from "react-intersection-observer";
import { useEffect } from "react";
import { Program } from "@/types/program";
import ProgramCard from "./ProgramCard";
import { Alert, AlertDescription } from "@/components/ui/alert";

interface ProgramsListProps {
  programs: Program[];
  isLoading: boolean;
  error: Error | null;
  hasNextPage: boolean;
  onLoadMore: () => void;
}

export default function ProgramsList({
  programs,
  isLoading,
  error,
  hasNextPage,
  onLoadMore,
}: ProgramsListProps) {
  const { ref, inView } = useInView();

  useEffect(() => {
    if (inView && hasNextPage && !isLoading) {
      onLoadMore();
    }
  }, [inView, hasNextPage, isLoading, onLoadMore]);

  if (error) {
    return (
      <Alert variant="destructive">
        <AlertDescription>
          Failed to load programs. Please try again later.
        </AlertDescription>
      </Alert>
    );
  }

  return (
    <div className="space-y-6">
      {programs.map((program) => (
        <ProgramCard key={program.id} program={program} />
      ))}
      
      {hasNextPage && (
        <div ref={ref} className="w-full h-20 flex items-center justify-center">
          {isLoading && (
            <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary" />
          )}
        </div>
      )}

      {!hasNextPage && programs.length === 0 && !isLoading && (
        <div className="text-center py-12">
          <h3 className="text-lg font-semibold mb-2">No programs found</h3>
          <p className="text-muted-foreground">
            Try adjusting your search criteria
          </p>
        </div>
      )}
    </div>
  );
}